==> bloodhound_8.2.0.orig.tar.gz: BloodHound-8.2.0/packages/javascript/bh-shared-ui/src/components/AppIcon/Icons/index.ts <==
// Copyright 2025 Specter Ops, Inc.
//
// Licensed under the Apache License, Version 2.0
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// SPDX-License-Identifier: Apache-2.0

export * from './AttackPaths';
export * from './BHCELogo';
export * from './BHCELogoFull';
export * from './BHELogo';
export * from './BHELogoFull';
export * from './BarChart';
export * from './CalendarDay';
export * from './CaretDown';
export * from './CaretUp';
export * from './Compass';
export * from './DataAlert';
export * from './Diamond';
export * from './Disabled';
export * from './Download';
export * from './EclipseCircle';
export * from './Equals';
export * from './FileMagnifyingGlass';
export * from './FilterOutline';
export * from './Findings';
export * from './Info';
export * from './LineChart';
export * from './Logout';
export * from './MagnifyingGlass';
export * from './Shield';
export * from './SortAsc';
export * from './SortDesc';
export * from './SortEmpty';
export * from './TierZero';
export * from './Upload';
export * from './User';
export * from './UserCog';
export * from './VerticalEllipsis';
export * from './Zones';

==> bloodhound_8.3.1.orig.tar.gz: BloodHound-8.3.1/packages/javascript/bh-shared-ui/src/components/AppIcon/Icons/index.ts <==
// Copyright 2025 Specter Ops, Inc.
//
// Licensed under the Apache License, Version 2.0
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// SPDX-License-Identifier: Apache-2.0

export * from './AttackPaths';
export * from './BHCELogo';
export * from './BHCELogoFull';
export * from './BHELogo';
export * from './BHELogoFull';
export * from './BarChart';
export * from './CalendarDay';
export * from './CaretDown';
export * from './CaretUp';
export * from './CertStatus';
export * from './Compass';
export * from './DataAlert';
export * from './Diamond';
export * from './Disabled';
export * from './DownArrow';
export * from './Download';
export * from './EclipseCircle';
export * from './Equals';
export * from './FileMagnifyingGlass';
export * from './FilterOutline';
export * from './Findings';
export * from './Info';
export * from './LargeRightArrow';
export * from './LineChart';
export * from './LinedPaper';
export * from './Logout';
export * from './MagnifyingGlass';
export * from './Shield';
export * from './SortAsc';
export * from './SortDesc';
export * from './SortEmpty';
export * from './TierZero';
export * from './Upload';
export * from './User';
export * from './UserCog';
export * from './VerticalEllipsis';
export * from './Zones';
